# -*- coding: utf-8 -*-
# Author:   $Author: merkosh $
# Revision: $Rev: 692 $
############################################################################
#    Copyright (C) 2005 by Uwe Mayer                                       #
#    merkosh@hadiko.de                                                     #
#                                                                          #
#    This program is free software; you can redistribute it and/or modify  #
#    it under the terms of the GNU General Public License as published by  #
#    the Free Software Foundation; either version 2 of the License, or     #
#    (at your option) any later version.                                   #
#                                                                          #
#    This program is distributed in the hope that it will be useful,       #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of        #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         #
#    GNU General Public License for more details.                          #
#                                                                          #
#    You should have received a copy of the GNU General Public License     #
#    along with this program; if not, write to the                         #
#    Free Software Foundation, Inc.,                                       #
#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
############################################################################
import os
from os.path import join as fjoin, exists as fexists


pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "prefix")
installdir = fjoin(pythondir, "lmc")

if (os.getcwd() == "/home/merkosh/src/lmc/src"):
	installdir = "."

version = "0.12.8"
scriptdir = fjoin(installdir, "scripts")
resourcedir = fjoin(installdir, "resources")

use_listviewsort = ("yes" == "yes")

have_eject = ("/usr/bin/eject" != "no")
have_tcprobe = ("/home/merkosh/usr/bin/tcprobe" != "no")

